<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ShowDesktop</name>
    <message>
        <location filename="../showdesktop.cpp" line="44"/>
        <source>Show desktop</source>
        <translation>Asztalmegjelenítés</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="66"/>
        <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>Asztalmegjelenítés: A &apos;%1&apos; gyorsbillentyű nem regisztrálható</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="51"/>
        <source>Show Desktop</source>
        <translation>Asztalmegjelenítés</translation>
    </message>
</context>
</TS>
